
clear all
********************************************************************************
********************************************************************************
********************************************************************************
use $data\final_dataset, clear


******************************************************************************************************
********************************  Baseline  **********************************************************   
******************************************************************************************************
 
preserve  
keep if fixed ==1  
drop if loan_yrs ==0 | loan_yrs > 5  
keep if date>=q(2011q1) & date<=q(2013q2)
keep if credpai =="4+" |   credpai =="4"  |   credpai =="5+" 

gen bbb =  spread  if credpai =="4+"
gen ccc =  spread  if credpai =="4"
gen ddd =  spread  if credpai =="5+"
gen one =4
gen four =1
collapse (mean) one four  bbb ccc ddd, by (date_m)
gen diff = ccc - bbb
tsset  date_m
twoway  (tsline bbb,  lcolor(black) lpattern(shortdash)) ///
    || (tsline ccc,  lcolor(black) lpattern(longdash_dot)) ///
    || (tsline ddd,  lcolor(black) lpattern(dot)) ///
	|| (tsline one,  lcolor(white) lpattern(solid) ) ///
	|| (tsline four,  lcolor(white) lpattern(solid) ) ///
    ||  ,  ttitle("") ytitle("Spread above Eonia") ///
	 tline(623,lcolor(black) )   tlabel(623  "ACC", add angle(vertical))  ///      
	 legend( cols(2) order(1 "4+ GC Eligible"  2 "4 ACC Eligible" 3 "5+ Non-Eligible"))
restore	
	
graph export $results\common_trends.pdf, replace
  
********************************************************************************
********************************************************************************

keep if fixed ==1  
drop if loan_yrs == 0 
drop if loan_yrs > 5  
 
gen obs =1
bysort siren: egen nb_loans = total(obs)

label variable nb_loans  "Nb of Loans" 
label variable total_assets  "Total Assets (KEUR)" 
label variable credit  "Credit Volume (KEUR)" 

replace credit = int(credit / 1000)
 
* pre 
preserve
*keep if post != . & treated !=.  
drop if post == . | treated == .
keep if post ==0
estpost tabstat spread credit loan_yrs investment secured , by(credpai)  ///
statistics(n mean sd p1 p50 p99) columns(statistics) listwise nototal 
est store a
restore

* post
preserve 
drop if post == . | treated == .
keep if post ==1
estpost tabstat spread credit loan_yrs investment secured , by(credpai)  ///
statistics(n mean sd p1 p50 p99) columns(statistics) listwise nototal 
est store b
restore
 
esttab a using $results\DS_Loans_pre.tex, replace label noobs nonumber lines nodepvars nogaps   collabels(none)  nomtitles   ///
 cells("count mean (fmt(%9.2f)) sd (fmt(%9.2f)) p1 (fmt(%9.2f)) p50 (fmt(%9.2f))  p99 (fmt(%9.2f))")   ///
	fragment 

esttab b using $results\DS_Loans_post.tex,  replace label noobs nonumber lines nodepvars nogaps   collabels(none)  nomtitles   ///
 cells("count mean (fmt(%9.2f)) sd (fmt(%9.2f)) p1 (fmt(%9.2f)) p50 (fmt(%9.2f))  p99 (fmt(%9.2f))")  ///
	fragment

**********************************************************************************
* pre
preserve
drop if post == . | treated == . 
keep if post ==0
 collapse (median) total_assets debt_assets sales_assets firm_age group nb_loans, by (siren credpai post)  
estpost tabstat total_assets  debt_assets sales_assets firm_age group nb_loans, by(credpai)  ///
statistics(n mean sd p1 p50 p99) columns(statistics) listwise  nototal
est store c
restore

*post
preserve 
drop if post == . | treated == .
keep if post ==1 
 collapse (median) total_assets debt_assets sales_assets firm_age group nb_loans, by (siren credpai post) 
estpost tabstat total_assets  debt_assets sales_assets firm_age group nb_loans, by(credpai)  ///
statistics(n mean sd p1 p50 p99) columns(statistics)  listwise  nototal
est store d
restore
 
esttab c using $results\DS_Firms_pre.tex, replace label noobs nonumber lines nodepvars nogaps   collabels(none)  nomtitles   ///
 cells("count mean (fmt(%9.2f)) sd (fmt(%9.2f)) p1 (fmt(%9.2f)) p50 (fmt(%9.2f))  p99 (fmt(%9.2f))")  ///
	fragment

esttab d using $results\DS_Firms_post.tex,  replace label noobs nonumber lines nodepvars nogaps   collabels(none)  nomtitles   ///
 cells("count mean (fmt(%9.2f)) sd (fmt(%9.2f)) p1 (fmt(%9.2f)) p50 (fmt(%9.2f))  p99 (fmt(%9.2f))")  ///
	fragment

 
********************************************************************************
********************************************************************************
******************************************************************************** 
 
preserve
drop if post == . | treated == .

* Balance Test Pre-Period Not treatd = 4+ (0) vs Treated = 4 (1)
tabstat log_loan_size loan_yrs investment secured  ///
		log_total_assets debt_assets sales_assets firm_age group ///
                if post == 0 & treated==0, /// 
                 f(%9.2g) stat(mean) col(stats) long missing save
matrix output0 = r(StatTotal)'

tabstat log_loan_size loan_yrs investment secured  ///
		log_total_assets debt_assets sales_assets firm_age group ////
                if post == 0 & treated==1, /// 
                 f(%9.2g) stat(mean) col(stats) long missing save
matrix output1 = r(StatTotal)'

tabstat log_loan_size loan_yrs investment secured  ///
		log_total_assets debt_assets sales_assets firm_age group ///
                if post == 0 & treated==0, /// 
                 f(%9.2g) stat(variance) col(stats) long missing save
matrix output0var = r(StatTotal)'

tabstat log_loan_size loan_yrs investment secured  ///
		log_total_assets debt_assets sales_assets firm_age group ///
                if post == 0 & treated==1, /// 
                 f(%9.2g) stat(variance) col(stats) long missing save
matrix output1var = r(StatTotal)'

tabstat log_loan_size loan_yrs investment secured  ///
		log_total_assets debt_assets sales_assets firm_age group ///
                if post == 0 & treated==0, /// 
                 f(%9.2g) stat(sd) col(stats) long missing save
matrix output0sd = r(StatTotal)'

tabstat log_loan_size loan_yrs investment secured  ///
		log_total_assets debt_assets sales_assets firm_age group ///
                if post == 0 & treated==1, /// 
                 f(%9.2g) stat(sd) col(stats) long missing save
matrix output1sd = r(StatTotal)'


tabstat log_loan_size loan_yrs investment secured  ///
		log_total_assets debt_assets sales_assets firm_age group ///
                if post == 0, ///  
                 f(%9.2g) stat(sd) col(stats) long missing save
matrix output_sd = r(StatTotal)'

matrix stddiff10=(vecdiag(diag(output1 - output0)*(inv(cholesky(diag(output1var+output0var))))))'

matrix output4 = [output1 , output1sd,  output0 ,output0sd, stddiff10]
matrix colnames output4 = Mean_4 SD_4 Mean_4+ SD_4+ Std_Diff

matrix list output4

outtable using "$results\balance_test_pre", mat(output4) ///
                replace center  nobox label f(%9.2fc) 

 * Balance Test Post-Period
tabstat log_loan_size loan_yrs investment secured  ///
		log_total_assets debt_assets sales_assets firm_age group ///
                if post == 1 & treated==0, /// 
                 f(%9.2g) stat(mean) col(stats) long missing save
matrix output0 = r(StatTotal)'

tabstat log_loan_size loan_yrs investment secured  ///
		log_total_assets debt_assets sales_assets firm_age group ///
                if post == 1 & treated==1, /// 
                 f(%9.2g) stat(mean) col(stats) long missing save
matrix output1 = r(StatTotal)'

tabstat log_loan_size loan_yrs investment secured  ///
		log_total_assets debt_assets sales_assets firm_age group ///
                if post == 1 & treated==0, /// 
                 f(%9.2g) stat(variance) col(stats) long missing save
matrix output0var = r(StatTotal)'

tabstat log_loan_size loan_yrs investment secured  ///
		log_total_assets debt_assets sales_assets firm_age group ///
                if post == 1 & treated==1, /// 
                 f(%9.2g) stat(variance) col(stats) long missing save
matrix output1var = r(StatTotal)'

tabstat log_loan_size loan_yrs investment secured  ///
		log_total_assets debt_assets sales_assets firm_age group ///
                if post == 1 & treated==0, /// 
                 f(%9.2g) stat(sd) col(stats) long missing save
matrix output0sd = r(StatTotal)'

tabstat log_loan_size loan_yrs investment secured  ///
		log_total_assets debt_assets sales_assets firm_age group ///
                if post == 1 & treated==1, /// 
                 f(%9.2g) stat(sd) col(stats) long missing save
matrix output1sd = r(StatTotal)'


tabstat log_loan_size loan_yrs investment secured  ///
		log_total_assets debt_assets sales_assets firm_age group ///
                if post == 1, ///  
                 f(%9.2g) stat(sd) col(stats) long missing save
matrix output_sd = r(StatTotal)'

matrix stddiff10=(vecdiag(diag(output1 - output0)*(inv(cholesky(diag(output1var+output0var))))))'

matrix output5 = [output1 , output1sd,  output0 ,output0sd, stddiff10]

matrix list output5
*est store a
matrix colnames output5 = Mean_4 SD_4 Mean_4+ SD_4+ Std_Diff

outtable using "$results\balance_test_post", mat(output5) ///
                replace center  nobox label f(%9.2fc) 

				*clabel(statsfirms1)  
 *caption("Balance test of covariates Post-Period 2012q3-2013q2")

*pbalchk treated log_loan_size loan_yrs investment fixed log_total_assets debt_assets sales_assets group   if post == 1
 
restore

************************************************************************************
* New balanced sample tests - Revision 2019/09
************************************************************************************

* Question A.2: firm characteristics of rating 4, pre vs post
 
preserve
keep if post != . & treated == 1

* Balance Test Pre-Post Period, rating 4 only
tabstat log_loan_size loan_yrs investment secured  ///
		log_total_assets debt_assets sales_assets firm_age group ///
                if post == 0 & treated == 1, /// 
                 f(%9.2g) stat(mean) col(stats) long missing save
matrix output0 = r(StatTotal)'

tabstat log_loan_size loan_yrs investment secured  ///
		log_total_assets debt_assets sales_assets firm_age group ////
                if post == 1 & treated==1, /// 
                 f(%9.2g) stat(mean) col(stats) long missing save
matrix output1 = r(StatTotal)'

tabstat log_loan_size loan_yrs investment secured  ///
		log_total_assets debt_assets sales_assets firm_age group ///
                if post == 0 & treated == 1, /// 
                 f(%9.2g) stat(variance) col(stats) long missing save
matrix output0var = r(StatTotal)'

tabstat log_loan_size loan_yrs investment secured  ///
		log_total_assets debt_assets sales_assets firm_age group ///
                if post == 1 & treated==1, /// 
                 f(%9.2g) stat(variance) col(stats) long missing save
matrix output1var = r(StatTotal)'

tabstat log_loan_size loan_yrs investment secured  ///
		log_total_assets debt_assets sales_assets firm_age group ///
                if post == 0 & treated == 1, /// 
                 f(%9.2g) stat(sd) col(stats) long missing save
matrix output0sd = r(StatTotal)'

tabstat log_loan_size loan_yrs investment secured  ///
		log_total_assets debt_assets sales_assets firm_age group ///
                if post == 1 & treated==1, /// 
                 f(%9.2g) stat(sd) col(stats) long missing save
matrix output1sd = r(StatTotal)'


tabstat log_loan_size loan_yrs investment secured  ///
		log_total_assets debt_assets sales_assets firm_age group ///
                if post == 0, ///  
                 f(%9.2g) stat(sd) col(stats) long missing save
matrix output_sd = r(StatTotal)'

matrix stddiff10=(vecdiag(diag(output1 - output0)*(inv(cholesky(diag(output1var+output0var))))))'

matrix output4 = [output1 , output1sd,  output0 ,output0sd, stddiff10]
matrix colnames output4 = Mean_4post SD_4post Mean_4pre SD_4pre Std_Diff

matrix list output4

outtable using "$results\balance_test_4_prepost.tex", mat(output4) ///
                replace center  nobox label f(%9.2fc) 

restore

***				
* Question A.2: firm characteristics of rating 4+, pre vs post
 
preserve
keep if post != . & treated == 0

* Balance Test Pre-Post Period, rating 4+
tabstat log_loan_size loan_yrs investment secured  ///
		log_total_assets debt_assets sales_assets firm_age group ///
                if post == 0 & treated == 0, /// 
                 f(%9.2g) stat(mean) col(stats) long missing save
matrix output0 = r(StatTotal)'

tabstat log_loan_size loan_yrs investment secured  ///
		log_total_assets debt_assets sales_assets firm_age group ////
                if post == 1 & treated==0, /// 
                 f(%9.2g) stat(mean) col(stats) long missing save
matrix output1 = r(StatTotal)'

tabstat log_loan_size loan_yrs investment secured  ///
		log_total_assets debt_assets sales_assets firm_age group ///
                if post == 0 & treated == 0, /// 
                 f(%9.2g) stat(variance) col(stats) long missing save
matrix output0var = r(StatTotal)'

tabstat log_loan_size loan_yrs investment secured  ///
		log_total_assets debt_assets sales_assets firm_age group ///
                if post == 1 & treated==0, /// 
                 f(%9.2g) stat(variance) col(stats) long missing save
matrix output1var = r(StatTotal)'

tabstat log_loan_size loan_yrs investment secured  ///
		log_total_assets debt_assets sales_assets firm_age group ///
                if post == 0 & treated == 0, /// 
                 f(%9.2g) stat(sd) col(stats) long missing save
matrix output0sd = r(StatTotal)'

tabstat log_loan_size loan_yrs investment secured  ///
		log_total_assets debt_assets sales_assets firm_age group ///
                if post == 1 & treated==0, /// 
                 f(%9.2g) stat(sd) col(stats) long missing save
matrix output1sd = r(StatTotal)'


tabstat log_loan_size loan_yrs investment secured  ///
		log_total_assets debt_assets sales_assets firm_age group ///
                if post == 0, ///  
                 f(%9.2g) stat(sd) col(stats) long missing save
matrix output_sd = r(StatTotal)'

matrix stddiff10=(vecdiag(diag(output1 - output0)*(inv(cholesky(diag(output1var+output0var))))))'

matrix output4 = [output1 , output1sd,  output0 ,output0sd, stddiff10]
matrix colnames output4 = Mean_4+post SD_4+post Mean_4+pre SD_4+pre Std_Diff

matrix list output4

outtable using "$results\balance_test_4plus_prepost.tex", mat(output4) ///
                replace center  nobox label f(%9.2fc) 

restore				

**
* Question A.1 / A.7 : firm characteristics of rating 5+, pre vs post
* here: convince that 5+ is not good control group
 
preserve
replace treated = 2 if credpai == "5+"
keep if post != . & credpai == "5+"

* Balance Test Pre-Post Period, rating 5+
tabstat log_loan_size loan_yrs investment secured  ///
		log_total_assets debt_assets sales_assets firm_age group ///
                if post == 0 & treated == 2, /// 
                 f(%9.2g) stat(mean) col(stats) long missing save
matrix output0 = r(StatTotal)'

tabstat log_loan_size loan_yrs investment secured  ///
		log_total_assets debt_assets sales_assets firm_age group ////
                if post == 1 & treated==2, /// 
                 f(%9.2g) stat(mean) col(stats) long missing save
matrix output1 = r(StatTotal)'

tabstat log_loan_size loan_yrs investment secured  ///
		log_total_assets debt_assets sales_assets firm_age group ///
                if post == 0 & treated == 2, /// 
                 f(%9.2g) stat(variance) col(stats) long missing save
matrix output0var = r(StatTotal)'

tabstat log_loan_size loan_yrs investment secured  ///
		log_total_assets debt_assets sales_assets firm_age group ///
                if post == 1 & treated==2, /// 
                 f(%9.2g) stat(variance) col(stats) long missing save
matrix output1var = r(StatTotal)'

tabstat log_loan_size loan_yrs investment secured  ///
		log_total_assets debt_assets sales_assets firm_age group ///
                if post == 0 & treated == 2, /// 
                 f(%9.2g) stat(sd) col(stats) long missing save
matrix output0sd = r(StatTotal)'

tabstat log_loan_size loan_yrs investment secured  ///
		log_total_assets debt_assets sales_assets firm_age group ///
                if post == 1 & treated==2, /// 
                 f(%9.2g) stat(sd) col(stats) long missing save
matrix output1sd = r(StatTotal)'


tabstat log_loan_size loan_yrs investment secured  ///
		log_total_assets debt_assets sales_assets firm_age group ///
                if post == 0, ///  
                 f(%9.2g) stat(sd) col(stats) long missing save
matrix output_sd = r(StatTotal)'

matrix stddiff10=(vecdiag(diag(output1 - output0)*(inv(cholesky(diag(output1var+output0var))))))'

matrix output4 = [output1 , output1sd,  output0 ,output0sd, stddiff10]
matrix colnames output4 = Mean_5+post SD_5+post Mean_5+pre SD_5+pre Std_Diff

matrix list output4

outtable using "$results\balance_test_5plus_prepost.tex", mat(output4) ///
                replace center  nobox label f(%9.2fc) 

restore				

**
* Question a.1/a.7: choice of control group
* Here show that 5+ bad control vs 4+

preserve
drop if treated == 0
replace treated = 0 if credpai == "5+"
keep if post != . & treated !=.

* Balance Test Pre-Period: 1/ rating 4, 0/ rating 5+ as control group
tabstat log_loan_size loan_yrs investment secured  ///
		log_total_assets debt_assets sales_assets firm_age group ///
                if post == 0 & treated==0, /// 
                 f(%9.2g) stat(mean) col(stats) long missing save
matrix output0 = r(StatTotal)'

tabstat log_loan_size loan_yrs investment secured  ///
		log_total_assets debt_assets sales_assets firm_age group ////
                if post == 0 & treated==1, /// 
                 f(%9.2g) stat(mean) col(stats) long missing save
matrix output1 = r(StatTotal)'

tabstat log_loan_size loan_yrs investment secured  ///
		log_total_assets debt_assets sales_assets firm_age group ///
                if post == 0 & treated==0, /// 
                 f(%9.2g) stat(variance) col(stats) long missing save
matrix output0var = r(StatTotal)'

tabstat log_loan_size loan_yrs investment secured  ///
		log_total_assets debt_assets sales_assets firm_age group ///
                if post == 0 & treated==1, /// 
                 f(%9.2g) stat(variance) col(stats) long missing save
matrix output1var = r(StatTotal)'

tabstat log_loan_size loan_yrs investment secured  ///
		log_total_assets debt_assets sales_assets firm_age group ///
                if post == 0 & treated==0, /// 
                 f(%9.2g) stat(sd) col(stats) long missing save
matrix output0sd = r(StatTotal)'

tabstat log_loan_size loan_yrs investment secured  ///
		log_total_assets debt_assets sales_assets firm_age group ///
                if post == 0 & treated==1, /// 
                 f(%9.2g) stat(sd) col(stats) long missing save
matrix output1sd = r(StatTotal)'


tabstat log_loan_size loan_yrs investment secured  ///
		log_total_assets debt_assets sales_assets firm_age group ///
                if post == 0, ///  
                 f(%9.2g) stat(sd) col(stats) long missing save
matrix output_sd = r(StatTotal)'

matrix stddiff10=(vecdiag(diag(output1 - output0)*(inv(cholesky(diag(output1var+output0var))))))'

matrix output4 = [output1 , output1sd,  output0 ,output0sd, stddiff10]
matrix colnames output4 = Mean_4 SD_4 Mean_5+ SD_5+ Std_Diff

matrix list output4

outtable using "$results\balance_test_pre_4vs5plus", mat(output4) ///
                replace center  nobox label f(%9.2fc) 

 * Balance Test Post-Period
tabstat log_loan_size loan_yrs investment secured  ///
		log_total_assets debt_assets sales_assets firm_age group ///
                if post == 1 & treated==0, /// 
                 f(%9.2g) stat(mean) col(stats) long missing save
matrix output0 = r(StatTotal)'

tabstat log_loan_size loan_yrs investment secured  ///
		log_total_assets debt_assets sales_assets firm_age group ///
                if post == 1 & treated==1, /// 
                 f(%9.2g) stat(mean) col(stats) long missing save
matrix output1 = r(StatTotal)'

tabstat log_loan_size loan_yrs investment secured  ///
		log_total_assets debt_assets sales_assets firm_age group ///
                if post == 1 & treated==0, /// 
                 f(%9.2g) stat(variance) col(stats) long missing save
matrix output0var = r(StatTotal)'

tabstat log_loan_size loan_yrs investment secured  ///
		log_total_assets debt_assets sales_assets firm_age group ///
                if post == 1 & treated==1, /// 
                 f(%9.2g) stat(variance) col(stats) long missing save
matrix output1var = r(StatTotal)'

tabstat log_loan_size loan_yrs investment secured  ///
		log_total_assets debt_assets sales_assets firm_age group ///
                if post == 1 & treated==0, /// 
                 f(%9.2g) stat(sd) col(stats) long missing save
matrix output0sd = r(StatTotal)'

tabstat log_loan_size loan_yrs investment secured  ///
		log_total_assets debt_assets sales_assets firm_age group ///
                if post == 1 & treated==1, /// 
                 f(%9.2g) stat(sd) col(stats) long missing save
matrix output1sd = r(StatTotal)'


tabstat log_loan_size loan_yrs investment secured  ///
		log_total_assets debt_assets sales_assets firm_age group ///
                if post == 1, ///  
                 f(%9.2g) stat(sd) col(stats) long missing save
matrix output_sd = r(StatTotal)'

matrix stddiff10=(vecdiag(diag(output1 - output0)*(inv(cholesky(diag(output1var+output0var))))))'

matrix output5 = [output1 , output1sd,  output0 ,output0sd, stddiff10]

matrix list output5
*est store a
matrix colnames output5 = Mean_4 SD_4 Mean_5+ SD_5+ Std_Diff

outtable using "$results\balance_test_post_4vs5plus", mat(output5) ///
                replace center  nobox label f(%9.2fc) 

restore



