
******************************************************************************************************
use $data\final_dataset, clear
******************************************************************************************************
destring depart, replace

** merge with HHI on bank loans by departement from CEFIT (cf 5*.do)
merge m:1 depart using $data\temp_cefit_hhi_2011.dta
drop _merge


**
macro define loancontrols investment loan_yrs secured 
macro define loancontrols2 investment loan_yrs log_loan_size  secured 
macro define firmcontrols log_total_assets debt_assets sales_assets group firm_age  
macro define fixed_effects Loan_Controls Firm_Controls Sector_Period Region_Period Bank_Period Quarter  
macro define labels Loan_Controls "Loan Controls" Firm_Controls "Firm Controls" Sector_Period "Sector_Period" Region_Period "Region_Period" Bank_Period "Bank_Period" Quarter "Quarter"

**
drop if loan_yrs ==0

label variable secured "Secured"
label variable fixed "Fixed"

capture drop post
capture drop pt 
gen postacc = 1 if  date>=q(2012q2) & date<=q(2013q1)
replace postacc =0 if year ==2011
label variable postacc "POST"
 
gen pt = postacc*treated
label variable pt "POST*Rating4"

save $data\toto.dta, replace
******************************************************************************************************
********************************  Baseline  **********************************************************
******************************************************************************************************
   
preserve 
keep if fixed ==1
gen dummy =1
drop if loan_yrs > 5 | treated ==. 

est clear
 
reg spread treated postacc  pt  ///
 , vce(cluster Bank_date)
eststo A

reghdfe spread treated postacc  pt $loancontrols ///
 ,  absorb  (dummy)   vce(cluster Bank_date)
estimates store B

reghdfe spread treated postacc  pt $loancontrols $firmcontrols  ///
 ,  absorb  (dummy)  vce(cluster Bank_date)
estimates store C

reghdfe spread treated  pt  $loancontrols $firmcontrols ///
,  absorb  (Sector_Period Region_Period)   vce(cluster Bank_date)
 estimates store D
  estfe D, labels(Sector_Period "Sector_Period" Region_Period "Region_Period")

reghdfe spread treated pt $loancontrols $firmcontrols ///
,  absorb  (Sector_Period Region_Period Bank_Period)   vce(cluster Bank_date)
estimates store E
 estfe E, labels(Sector_Period "Sector_Period" Region_Period "Region_Period" Bank_Period "Bank_Period")

reghdfe spread treated pt  $loancontrols $firmcontrols   ///
, absorb (Sector_Period Region_Period Bank_Period Quarter) vce(cluster Bank_date)
estimates store F
 estfe F, labels(Sector_Period "Sector_Period" Region_Period "Region_Period" Bank_Period "Bank_Period" Quarter "Quarter")
 
 
esttab  A B C D E F  using "$results\regression1rev.tex", ///
	replace label  nodepvars nogaps  collabels(none) nomtitles noconstant  ///
    star(* 0.10 ** 0.05 *** 0.01) ///
	cells("b(fmt(3)star)" "se(fmt(3)par)") ///
	indicate(`r(indicate_fe)') /// 
	stats( N r2_a   , fmt(0 3) layout("\multicolumn{1}{S}{@}" "\multicolumn{1}{S}{@}") labels(`"Observations"'  `"Adj. R^{2}\"'))   ///
	fragment

 restore


******************************************************************************************************
********************************  Robustness  ********************************************************   
******************************************************************************************************
estimates clear
est clear

preserve
keep if fixed ==1
drop if loan_yrs > 5 | treated ==. 
reghdfe spread treated pt  $loancontrols $firmcontrols , absorb($fixed_effects)  vce(cl Bank_date)
estimates store A
restore
   estfe A,  labels($labels)
   
preserve
keep if fixed ==1
keep if loan_yrs > 5  
drop if  treated ==. 
reghdfe spread treated pt  $loancontrols $firmcontrols , absorb($fixed_effects)  vce(cl Bank_date)
estimates store B
restore
 estfe B,  labels($labels)
 
preserve  
keep if fixed ==1
drop if loan_yrs > 5  
drop pt
replace treated = 1 if credpai == "3"
drop if treated ==. | credpai == "4"
gen pt = postacc*treated
label variable pt "POST*Rating4"
reghdfe spread treated pt  $loancontrols $firmcontrols , absorb($fixed_effects)  vce(cl Bank_date)
estimates store C
restore
   estfe C,  labels($labels)
   
preserve
keep if fixed ==1
drop if loan_yrs > 5  
drop pt
replace treated = 0 if credpai == "5+"
drop if treated ==. |  credpai == "4+"
gen pt = postacc*treated
label variable pt "POST*Rating4"
reghdfe spread treated pt  $loancontrols $firmcontrols , absorb($fixed_effects)  vce(cl Bank_date)
estimates store D
restore
   estfe D, labels($labels)
   
*including variable rate loans
preserve
*keep if fixed ==1
drop if loan_yrs > 5 | treated ==. 
reghdfe spread treated pt  $loancontrols $firmcontrols fixed, absorb($fixed_effects)  vce(cl Bank_date)
estimates store E
restore
   estfe E,  labels($labels)
   
*maturity matched
preserve
replace  spread = tese - yield 
keep if fixed ==1
drop if loan_yrs > 5 | treated ==. 
reghdfe spread treated pt  $loancontrols $firmcontrols , absorb($fixed_effects)  vce(cl Bank_date)
estimates store F
restore
   estfe F,  labels($labels)
   
*sector, region, bank quarter fixed effects
preserve
drop Bank_Period  Sector_Period Region_Period
egen Bank_Quarter = group(newcib date)
egen Sector_Region_Quarter = group(statinfo Region date) 
keep if fixed ==1
drop if loan_yrs > 5 | treated ==. 
reghdfe spread treated pt  $loancontrols $firmcontrols , absorb(Loan_Controls Firm_Controls Sector_Region_Quarter Bank_Quarter)  vce(cl Bank_date)
estimates store G
restore
   estfe G,  labels($labels)


esttab A B C D E F G using "$results\regression_robustrev.tex" ///
	, replace nodepvars nogaps label collabels(none)  nomtitles    ///
     keep(treated pt) ///
    star(* 0.10 ** 0.05 *** 0.01) ///
	cells("b(fmt(3)star)" "se(fmt(3)par)") ///
	indicate(`r(indicate_fe)') /// 
	stats( N r2_a   , fmt(0 3) layout("\multicolumn{1}{S}{@}" "\multicolumn{1}{S}{@}") labels(`"Observations"'  `"Adj. R^{2}\"'))     ///
	fragment


******************************************************************************************************
******************************  Heterogenous banks: High/ low no middle bank  ********************** 
****************************************************************************************************** 
use $data\toto.dta, clear

estimates clear 
set more off
keep if fixed ==1
 
preserve
drop if loan_yrs > 5 | treated ==. 
reghdfe spread treated pt  $loancontrols $firmcontrols   ///
, absorb (Sector_Period Region_Period Bank_Period Quarter) vce(cluster Bank_date)
estimates store A3
 estfe A3, labels(Sector_Period "Sector_Period" Region_Period "Region_Period" Bank_Period "Bank_Period" Quarter "Quarter")
restore
 
preserve
*gen d_usage = usage_ltro - usage_ratio
gen high_d_usage =1 if  n/*confidential list of banks here*/
replace high_d_usage = 0 if  /*confidential list of banks here*/
drop if newcib == /*confidential list of banks here*/ 
gen bt = high_d_usage*treated
gen ptb = pt*high_d_usage
drop if loan_yrs > 5 | treated ==. 
reghdfe spread treated pt bt ptb $loancontrols $firmcontrols , absorb($fixed_effects)  vce(cl Bank_date)
estimates store B3
restore
estfe B3, labels(Loan_Controls "Loan Controls" Firm_Controls "Firm Controls" Purpose_Period "Investment_Period" Sector_Period "Sector_Period" Region_Period "Region_Period" Bank_Period "Bank_Period" Quarter "Quarter")

preserve      
*gen d_borrowed_pledged = (REFI_cum_ltro - REFI_cum) / (pledged - REFI_cum)
gen high_LTRO =1    if  /*confidential list of banks here*/ 
replace high_LTRO = 0 if /*confidential list of banks here*/
drop if newcib == /*confidential list of banks here*/ 
gen bt = high_LTRO*treated
gen ptb = pt*high_LTRO
drop if loan_yrs > 5 | treated ==. 
reghdfe spread treated pt bt ptb $loancontrols $firmcontrols , absorb($fixed_effects)  vce(cl Bank_date)
estimates store C3
restore
estfe C3, labels(Loan_Controls "Loan Controls" Firm_Controls "Firm Controls" Purpose_Period "Investment_Period" Sector_Period "Sector_Period" Region_Period "Region_Period" Bank_Period "Bank_Period" Quarter "Quarter")
 
preserve
gen bt = high_cc*treated
gen ptb = pt*high_cc
drop if newcib == /*confidential list of banks here*/
drop if loan_yrs > 5 | treated ==. 
reghdfe spread treated pt bt ptb $loancontrols $firmcontrols , absorb($fixed_effects)  vce(cl Bank_date)
estimates store D3
restore
estfe D3, labels(Loan_Controls "Loan Controls" Firm_Controls "Firm Controls" Purpose_Period "Investment_Period" Sector_Period "Sector_Period" Region_Period "Region_Period" Bank_Period "Bank_Period" Quarter "Quarter")
 
preserve
gen no_short = 1 if shortfall ==0
replace no_short = 0 if shortfall ==1
gen bt = high_cc*no_short
gen ptb = pt*no_short
drop if loan_yrs > 5 | treated ==. 
reghdfe spread treated pt bt ptb $loancontrols $firmcontrols , absorb($fixed_effects)  vce(cl Bank_date)
estimates store E3
restore
 estfe E3, labels($labels)

 esttab A3 C3 D3 E3 using $results\regression_bankhetero_8banksrev.tex, replace nodepvars nogaps label collabels(none) nomtitles   ///
     drop(investment loan_yrs secured log_total_assets debt_assets sales_assets group firm_age bt)  ///
    star(* 0.10 ** 0.05 *** 0.01) ///
	cells("b(fmt(3)star)" "se(fmt(3)par)") ///
	indicate(`r(indicate_fe)') /// 
	stats( N r2_a   , fmt(0 3) layout("\multicolumn{1}{S}{@}" "\multicolumn{1}{S}{@}") labels(`"Observations"'  `"Adj. R^{2}\"'))     ///
	fragment
 
******************************************************************************************************
******************************  Heterogenous banks: High/ low with middle bank  ********************** 
****************************************************************************************************** 
use $data\toto.dta, clear
**
estimates clear 
set more off
keep if fixed ==1

preserve
drop if loan_yrs > 5 | treated ==. 
reghdfe spread treated pt  $loancontrols $firmcontrols   ///
, absorb (Sector_Period Region_Period Bank_Period Quarter) vce(cluster Bank_date)
estimates store A3
 estfe A3, labels(Sector_Period "Sector_Period" Region_Period "Region_Period" Bank_Period "Bank_Period" Quarter "Quarter")
restore
 
preserve
gen high_d_usage =1 if  /*confidential list of banks here*/
replace high_d_usage = 0 if  /*confidential list of banks here*/
gen bt = high_d_usage*treated
gen ptb = pt*high_d_usage
la var ptb "POST*Rating4*X"  
drop if loan_yrs > 5 | treated ==. 
reghdfe spread treated pt bt ptb $loancontrols $firmcontrols , absorb($fixed_effects)  vce(cl Bank_date)
estimates store B3
restore
estfe B3, labels(Loan_Controls "Loan Controls" Firm_Controls "Firm Controls" Purpose_Period "Investment_Period" Sector_Period "Sector_Period" Region_Period "Region_Period" Bank_Period "Bank_Period" Quarter "Quarter")

preserve      
gen high_LTRO =1    if  /*confidential list of banks here*/
replace high_LTRO = 0 if /*confidential list of banks here*/   
gen bt = high_LTRO*treated
gen ptb = pt*high_LTRO
la var ptb "POST*Rating4*X"  
drop if loan_yrs > 5 | treated ==. 
reghdfe spread treated pt bt ptb $loancontrols $firmcontrols , absorb($fixed_effects)  vce(cl Bank_date)
estimates store C3
restore
estfe C3, labels(Loan_Controls "Loan Controls" Firm_Controls "Firm Controls" Purpose_Period "Investment_Period" Sector_Period "Sector_Period" Region_Period "Region_Period" Bank_Period "Bank_Period" Quarter "Quarter")
 
preserve
gen bt = high_cc*treated
gen ptb = pt*high_cc
la var ptb "POST*Rating4*X"  
drop if loan_yrs > 5 | treated ==. 
reghdfe spread treated pt bt ptb $loancontrols $firmcontrols , absorb($fixed_effects)  vce(cl Bank_date)
estimates store D3
restore
estfe D3, labels(Loan_Controls "Loan Controls" Firm_Controls "Firm Controls" Purpose_Period "Investment_Period" Sector_Period "Sector_Period" Region_Period "Region_Period" Bank_Period "Bank_Period" Quarter "Quarter")
 
preserve
gen no_short = 1 if shortfall ==0
replace no_short = 0 if shortfall ==1
gen bt = high_cc*no_short
gen ptb = pt*no_short
la var ptb "POST*Rating4*X"  
drop if loan_yrs > 5 | treated ==. 
reghdfe spread treated pt bt ptb $loancontrols $firmcontrols , absorb($fixed_effects)  vce(cl Bank_date)
estimates store E3
restore
 estfe E3, labels($labels)

preserve      
** add dichotomic variable about level of bank spreads 
gen high_cds = (newcib ==30003 | newcib == 30066 | newcib == 30076 | newcib ==22040)
/* high_cds -  cds in Sep 2011
*/
gen bt = high_cds*treated
gen ptb = pt*high_cds
la var ptb "POST*Rating4*X"  
drop if loan_yrs > 5 | treated ==. 
reghdfe spread treated pt bt ptb $loancontrols $firmcontrols , absorb($fixed_effects)  vce(cl Bank_date)
estimates store F3
restore
estfe F3, labels(Loan_Controls "Loan Controls" Firm_Controls "Firm Controls" Purpose_Period "Investment_Period" Sector_Period "Sector_Period" Region_Period "Region_Period" Bank_Period "Bank_Period" Quarter "Quarter")

preserve      
** add dichotomic varibale about change of bank spreads 
gen high_cds_change =  (newcib == 30003 | newcib ==30076  | newcib == 30066 | newcib == 22040  | newcib == 30004)
/* high_cds_change - change in cds between Sep 2010  and Sep 2011
*/
gen bt = high_cds_change*treated
gen ptb = pt*high_cds_change
la var ptb "POST*Rating4*X"  
drop if loan_yrs > 5 | treated ==. 
reghdfe spread treated pt bt ptb $loancontrols $firmcontrols , absorb($fixed_effects)  vce(cl Bank_date)
estimates store G3
restore
estfe G3, labels(Loan_Controls "Loan Controls" Firm_Controls "Firm Controls" Purpose_Period "Investment*Period" Sector_Period "Sector*Period" Region_Period "Region*Period" Bank_Period "Bank*Period" Quarter "Quarter")
  

 
esttab A3 C3 D3 E3 F3 G3 using $results\regression_bankhetero_9banksrev.tex, replace nodepvars nogaps label collabels(none)    ///
     keep(treated pt ptb)  ///
    star(* 0.10 ** 0.05 *** 0.01) ///
	cells("b(fmt(3)star)" "se(fmt(3)par)") ///
	mtitle("Baseline" "High squeeze" "High CC" "No EBA shortfall" "High CDS" "High $\Delta$ CDS") ///
	indicate(`r(indicate_fe)') /// 
	stats( N r2_a   , fmt(0 3) labels("Observations"  "Adj. $R^{2}$"))     ///
	fragment
  
 
 
esttab A3 C3 D3 E3 F3 G3 , replace nodepvars nogaps label collabels(none)    ///
     keep(treated pt ptb)  ///
    star(* 0.10 ** 0.05 *** 0.01) ///
	cells("b(fmt(3)star)" "se(fmt(3)par)") ///
	mtitle("Baseline" "High squeeze" "High CC" "No EBA shortfall" "High CDS" "High $\Delta$ CDS") ///
	indicate(`r(indicate_fe)') /// 
	stats( N r2_a   , fmt(0 3) labels("Observations"  "Adj. $R^{2}$"))     ///
	fragment
  
******************************************************************************************************
**  New tests for revision : interaction with some firm characteristics + competition
****************************************************************************************************** 
use $data\toto.dta, clear


keep if fixed ==1
gen dummy =1
drop if loan_yrs > 5 | treated ==. 

merge m:1 siren newcib date using "$data\scr_addrelationship.dta"
drop if _merge==2
drop _merge

rename commitment commitment_1

* recode missing values into 0: means that loan is new loan here
foreach x in commitment_1 nbbk_1 lnbbk_1 sharecom_1 mainbk_1 {
	recode `x' (.=0)
	}



* create firm tags
egen tag_siren=tag(siren)
gen relevant = (loan_yrs <= 5 | treated ==.)

tab categorie_lme if tag_siren==1

su total_assets if tag_siren==1 & relevant == 1, detail
bysort credpai relevant: su total_assets  if tag_siren==1, detail
bysort credpai relevant: egen total_assets_high = pctile(total_assets)  if tag_siren==1, p(90) 
bysort credpai relevant: egen total_assets_low = pctile(total_assets)  if tag_siren==1, p(50) 
gen high_size_temp = 1 if total_assets >= total_assets_high & tag_siren==1
bysort siren: egen high_size=max(high_size_temp)
gen low_size_temp = 1 if total_assets <= total_assets_low & tag_siren==1
bysort siren: egen low_size=max(low_size_temp)

su debt_assets, detail
bysort credpai relevant: su debt_assets, detail
bysort credpai relevant: egen debt_assets_high = pctile(debt_assets)  if tag_siren==1, p(75) 
bysort credpai relevant: egen debt_assets_low = pctile(debt_assets)  if tag_siren==1, p(50) 
gen high_lev_temp = 1 if debt_assets >= debt_assets_high & tag_siren==1
bysort siren: egen high_lev=max(high_lev_temp)
gen low_lev_temp = 1 if debt_assets <= debt_assets_low & tag_siren==1
bysort siren: egen low_lev=max(low_lev_temp)

*
gen X = 0
gen ptX = 0

la var X "X"
la var ptX "POST*ACC*X"

**
eststo clear

* competition
tab high_compet 

replace X = (high_compet ==1)
replace ptX = pt*X
la var ptX "POST*ACC*X"
drop if loan_yrs > 5 | treated ==.
* keep if high_lev ==1
reghdfe spread treated pt ptX X $loancontrols $firmcontrols  ///
	, absorb (Loan_Controls Firm_Controls Sector_Period Region_Period Bank_Period Quarter) vce(cluster Bank_date)
est store Z

estfe Z, labels(Loan_Controls "Loan Controls" Firm_Controls "Firm Controls" Sector_Period "Sector_Period" Region_Period "Region_Period" Bank_Period "Bank_Period" Quarter "Quarter")




* size of firms : single out micro firms (<10 staff as of LME)


replace X = (categorie_lme == "1. Microentreprise")
replace ptX = pt*X
la var ptX "POST*ACC*X"
drop if loan_yrs > 5 | treated ==.
reghdfe spread treated pt ptX X $loancontrols $firmcontrols  ///
, absorb (Loan_Controls Firm_Controls Sector_Period Region_Period Bank_Period Quarter) vce(cluster Bank_date)
est store A

estfe A, labels(Loan_Controls "Loan Controls" Firm_Controls "Firm Controls" Sector_Period "Sector_Period" Region_Period "Region_Period" Bank_Period "Bank_Period" Quarter "Quarter")

* leverage of firms

replace X = (high_lev ==1)
replace ptX = pt*X
la var ptX "POST*ACC*X"
drop if loan_yrs > 5 | treated ==.
reghdfe spread treated pt ptX X $loancontrols $firmcontrols  ///
, absorb (Loan_Controls Firm_Controls Sector_Period Region_Period Bank_Period Quarter) vce(cluster Bank_date)
est store C

estfe C, labels(Loan_Controls "Loan Controls" Firm_Controls "Firm Controls" Sector_Period "Sector_Period" Region_Period "Region_Period" Bank_Period "Bank_Period" Quarter "Quarter")


* age of firms (below/above 10 years)

replace X = (firm_age ==1)
replace ptX = pt*X
la var ptX "POST*ACC*X"
drop if loan_yrs > 5 | treated ==.
reghdfe spread treated pt ptX X $loancontrols $firmcontrols  ///
, absorb (Loan_Controls Firm_Controls Sector_Period Region_Period Bank_Period Quarter) vce(cluster Bank_date)
est store E

estfe E, labels(Loan_Controls "Loan Controls" Firm_Controls "Firm Controls" Sector_Period "Sector_Period" Region_Period "Region_Period" Bank_Period "Bank_Period" Quarter "Quarter")

* belongs to a group

replace X = (group ==1)
replace ptX = pt*X
la var ptX "POST*ACC*X"
drop if loan_yrs > 5 | treated ==.
reghdfe spread treated pt ptX $loancontrols $firmcontrols  ///
, absorb (Loan_Controls Firm_Controls Sector_Period Region_Period Bank_Period Quarter) vce(cluster Bank_date)
est store K

estfe K, labels(Loan_Controls "Loan Controls" Firm_Controls "Firm Controls" Sector_Period "Sector_Period" Region_Period "Region_Period" Bank_Period "Bank_Period" Quarter "Quarter")


* multibank firm or not

replace X = (lnbbk_1 > 1)
replace ptX = pt*X
la var ptX "POST*ACC*X"
drop if loan_yrs > 5 | treated ==.
reghdfe spread treated pt ptX X $loancontrols $firmcontrols  ///
, absorb (Loan_Controls Firm_Controls Sector_Period Region_Period Bank_Period Quarter) vce(cluster Bank_date)
est store I

estfe I, labels(Loan_Controls "Loan Controls" Firm_Controls "Firm Controls" Sector_Period "Sector_Period" Region_Period "Region_Period" Bank_Period "Bank_Period" Quarter "Quarter")

* Secured loan

replace X = secured
replace ptX = pt*X
la var ptX "POST*ACC*X"
drop if loan_yrs > 5 | treated ==.
reghdfe spread treated pt ptX X $loancontrols $firmcontrols  ///
, absorb (Loan_Controls Firm_Controls Sector_Period Region_Period Bank_Period Quarter) vce(cluster Bank_date)
est store U

estfe U, labels(Loan_Controls "Loan Controls" Firm_Controls "Firm Controls" Sector_Period "Sector_Period" Region_Period "Region_Period" Bank_Period "Bank_Period" Quarter "Quarter")

* Maturity > 3 y

replace X = (loan_yrs >= 3)
replace ptX = pt*X
la var ptX "POST*ACC*X"
drop if loan_yrs > 5 | treated ==.
reghdfe spread treated pt ptX X $loancontrols $firmcontrols  ///
, absorb (Loan_Controls Firm_Controls Sector_Period Region_Period Bank_Period Quarter) vce(cluster Bank_date)
est store T

estfe T, labels(Loan_Controls "Loan Controls" Firm_Controls "Firm Controls" Sector_Period "Sector_Period" Region_Period "Region_Period" Bank_Period "Bank_Period" Quarter "Quarter")



* competition

esttab Z A C I U T using $results\regression_firmheterorev.tex ///
	, replace nodepvars nogaps label collabels(none)    ///
    keep(treated pt ptX)  ///
    star(* 0.10 ** 0.05 *** 0.01) ///
	cells("b(fmt(3)star)" "se(fmt(3)par)") ///
	indicate(`r(indicate_fe)') /// 
	stats( N r2_a   , fmt(0 3) layout("\multicolumn{1}{S}{@}" "\multicolumn{1}{S}{@}") labels(`"Observations"'  `"Adj. R^{2}\"')) ///
	mtitle("High compet" "Micro" "High Lev" "Multi-bank" "Secured" "$Mat>3y$") ///
	fragment

