* Additional regressions using SCR : quantity effects of ACC
***********************************************************************************

**
use  "$data\SCR_ACC_final_all", clear

** drop Corsica
drop if  depart=="2A" | depart == "2B"
destring depart, replace

** merge with HHI on bank loans by departement from CEFIT (cf 5*.do)
merge m:1 depart using $data\temp_cefit_hhi_2011.dta
drop _merge

**
merge m:1 siren newcib date using "$data\scr_addrelationship.dta"
drop if _merge==2
drop _merge

**
gen credpai = "4+" if rating_ref == 4
replace credpai = "4" if rating_ref == 5
replace credpai = "5+" if rating_ref == 6

gen post = 1 if period ==2
replace post = 0 if period ==1
  
* create dummies ****************
*gen sector = int(d32/10)
egen sector_fe = group(sector) 
egen newcib_sector_fe = group(newcib sector) 
egen firm_year = group(siren post)
egen sector_region_year = group(sector region post)
egen sector_region  = group(sector region)

*******************************************************$
**************************************************************$
**************************************************************$

macro define firm_controls log_total_assets debt_assets sales_assets 
 
* NB: firms' ratios in natural levels, not in pp
label variable log_total_assets "Log Total Assets" 
label variable debt_assets "Debt/Assets" 
label variable sales_assets "Sales-to-Assets" 
label variable credit_growth_dec_fwd "$\Delta ln(L_{i,j})$" 

***
rename attrition_type3 attrition

* define treatment
capture drop treated
gen treated =1 if credpai  == "4"
replace treated =0 if credpai == "4+"
label variable treated "ACC Firm" 

* look for bank competition effect
gen highcomp_treated = high_compet * treated
la var high_compet "High compet."
la var highcomp_treated "ACC * High compet."


* intensive margin
keep if post !=.
drop if attrition  == 1
gen dummy = 1
keep if period==1

* Drop outliers (p5-p95) for each of the two distributions (treated vs controls)
bysort treated: egen credit_growth_low = pctile(credit_growth_dec_fwd) if treated != ., p(5) 
bysort treated: egen credit_growth_high = pctile(credit_growth_dec_fwd) if treated != ., p(95) 
g outlier1 = (credit_growth_dec_fwd  < credit_growth_low |  credit_growth_dec_fwd > credit_growth_high) if treated != .

su credit_growth_dec_fwd if treated != . & outlier1 != 1, detail
tab highcomp_treated if treated != . & outlier1 != 1
** regressions 4 vs 4+
eststo clear
est clear

eststo A: reghdfe credit_growth_dec_fwd treated if treated != . & outlier1 != 1, absorb(dummy) vce(cluster newcib_sector_fe)
eststo B: reghdfe credit_growth_dec_fwd treated $firm_controls if treated != . & outlier1 != 1, absorb(dummy) vce(cluster newcib_sector_fe)
eststo C: reghdfe credit_growth_dec_fwd treated $firm_controls if treated != . & outlier1 != 1, absorb(sector_region) vce(cluster newcib_sector_fe)
estfe C, labels(sector_region "Sector*Region FE")
eststo D: reghdfe credit_growth_dec_fwd treated $firm_controls if treated != . & outlier1 != 1, absorb(sector_region newcib) vce(cluster newcib_sector_fe)
estfe D, labels(sector_region "Sector*Region FE" newcib "Bank FE")

* select multi-bank firms
eststo E: reghdfe credit_growth_dec_fwd treated $firm_controls if nbbk_1 > 1 & nbbk_1 < . & treated != . & outlier1 != 1, absorb(sector_region newcib) vce(cluster newcib_sector_fe)
estfe E, labels(sector_region "Sector*Region FE" newcib "Bank FE")
eststo F: reghdfe credit_growth_dec_fwd treated high_compet highcomp_treated $firm_controls if treated != . & outlier1 != 1, absorb(sector_region newcib) vce(cluster newcib_sector_fe)
estfe F, labels(sector_region "Sector*Region FE" newcib "Bank FE")


**************************************************************************************************************
* Alternative: 4 vs 5+


**
drop treated 
gen treated =1 if credpai == "4"
replace treated =0 if credpai == "5+"
label variable treated "ACC Firm" 

keep if post !=.
drop if attrition  == 1
keep if period==1

bysort treated: egen credit_growth_low2 = pctile(credit_growth_dec_fwd) if treated != ., p(5) 
bysort treated: egen credit_growth_high2 = pctile(credit_growth_dec_fwd) if treated != ., p(95) 
g outlier2 = (credit_growth_dec_fwd  < credit_growth_low2 |  credit_growth_dec_fwd > credit_growth_high2)  if treated != .
su credit_growth_dec_fwd, detail


eststo D1: reghdfe credit_growth_dec_fwd treated $firm_controls if treated != . & outlier2 != 1, absorb(sector_region newcib) vce(cluster newcib_sector_fe)
estfe D1, labels(sector_region "Sector Region" newcib "Bank FE")
	
	
esttab A B C D E F D1 using $results\qty_effect_revised.tex, replace  collabels(none) nocons ///
   label title(Impact of ACC on loan supply: volumes (intensive margin) \label{tab:volumes})   ///
	star(* 0.10 ** 0.05 *** 0.01) ///
	cells("b(fmt(3)star)" "se(fmt(3)par)") ///
	indicate(`r(indicate_fe)') /// 
	stats( N r2, fmt(0 3) layout("\multicolumn{1}{c}{@}" "\multicolumn{1}{c}{@}") labels(`"Observations"'  `"R$^{2}$"'))   

	
